@@ -164,13 +164,13 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_secretsmanager
-import aws_cdk.aws_ssm
-import constructs
+import aws_cdk.aws_secretsmanager as _aws_cdk_aws_secretsmanager_ceddda9d
+import aws_cdk.aws_ssm as _aws_cdk_aws_ssm_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class ActionEnvironmentSecret(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-github.ActionEnvironmentSecret",
 ):
@@ -180,14 +180,14 @@ class ActionEnvironmentSecret(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         environment: builtins.str,
-        github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+        github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
         repository: "IGitHubRepository",
         repository_secret_name: builtins.str,
-        source_secret: aws_cdk.aws_secretsmanager.ISecret,
+        source_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
         source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -203,19 +203,7 @@ class ActionEnvironmentSecret(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                environment: builtins.str,
-                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
-                repository: IGitHubRepository,
-                repository_secret_name: builtins.str,
-                source_secret: aws_cdk.aws_secretsmanager.ISecret,
-                source_secret_json_field: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f04c62400886edffc3fa16f507af446ec4ad2a2e1089c6fa98e572bd3f8f6d32)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ActionEnvironmentSecretProps(
@@ -247,10 +235,10 @@ class ActionEnvironmentSecretProps:
         self,
         *,
         environment: builtins.str,
-        github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+        github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
         repository: "IGitHubRepository",
         repository_secret_name: builtins.str,
-        source_secret: aws_cdk.aws_secretsmanager.ISecret,
+        source_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
         source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -264,24 +252,14 @@ class ActionEnvironmentSecretProps:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                environment: builtins.str,
-                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
-                repository: IGitHubRepository,
-                repository_secret_name: builtins.str,
-                source_secret: aws_cdk.aws_secretsmanager.ISecret,
-                source_secret_json_field: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__19458ba05b3c10d04dcaf1e2a1d6e605d210b81e75d59a1e981178b6f3a7adc5)
             check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
             check_type(argname="argument github_token_secret", value=github_token_secret, expected_type=type_hints["github_token_secret"])
             check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
             check_type(argname="argument repository_secret_name", value=repository_secret_name, expected_type=type_hints["repository_secret_name"])
             check_type(argname="argument source_secret", value=source_secret, expected_type=type_hints["source_secret"])
             check_type(argname="argument source_secret_json_field", value=source_secret_json_field, expected_type=type_hints["source_secret_json_field"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "environment": environment,
             "github_token_secret": github_token_secret,
             "repository": repository,
@@ -302,14 +280,14 @@ class ActionEnvironmentSecretProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def github_token_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
+    def github_token_secret(self) -> _aws_cdk_aws_secretsmanager_ceddda9d.ISecret:
         '''(experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
 
         :stability: experimental
         '''
         result = self._values.get("github_token_secret")
         assert result is not None, "Required property 'github_token_secret' is missing"
-        return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
+        return typing.cast(_aws_cdk_aws_secretsmanager_ceddda9d.ISecret, result)
 
     @builtins.property
     def repository(self) -> "IGitHubRepository":
@@ -332,14 +310,14 @@ class ActionEnvironmentSecretProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def source_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
+    def source_secret(self) -> _aws_cdk_aws_secretsmanager_ceddda9d.ISecret:
         '''(experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
 
         :stability: experimental
         '''
         result = self._values.get("source_secret")
         assert result is not None, "Required property 'source_secret' is missing"
-        return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
+        return typing.cast(_aws_cdk_aws_secretsmanager_ceddda9d.ISecret, result)
 
     @builtins.property
     def source_secret_json_field(self) -> typing.Optional[builtins.str]:
@@ -367,7 +345,7 @@ class ActionEnvironmentSecretProps:
 
 
 class ActionSecret(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-github.ActionSecret",
 ):
@@ -377,13 +355,13 @@ class ActionSecret(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+        github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
         repository: "IGitHubRepository",
         repository_secret_name: builtins.str,
-        source_secret: aws_cdk.aws_secretsmanager.ISecret,
+        source_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
         source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -398,18 +376,7 @@ class ActionSecret(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
-                repository: IGitHubRepository,
-                repository_secret_name: builtins.str,
-                source_secret: aws_cdk.aws_secretsmanager.ISecret,
-                source_secret_json_field: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c940bc65eade9a56398b94487dd33d25ad7688152385eb63583bfa67ab511b54)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ActionSecretProps(
@@ -438,10 +405,10 @@ class ActionSecretProps:
     def __init__(
         self,
         *,
-        github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+        github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
         repository: "IGitHubRepository",
         repository_secret_name: builtins.str,
-        source_secret: aws_cdk.aws_secretsmanager.ISecret,
+        source_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
         source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -454,22 +421,13 @@ class ActionSecretProps:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
-                repository: IGitHubRepository,
-                repository_secret_name: builtins.str,
-                source_secret: aws_cdk.aws_secretsmanager.ISecret,
-                source_secret_json_field: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__914972a093356563c05a92c585205514c45295c3c26e5e0063ed507e8833ba01)
             check_type(argname="argument github_token_secret", value=github_token_secret, expected_type=type_hints["github_token_secret"])
             check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
             check_type(argname="argument repository_secret_name", value=repository_secret_name, expected_type=type_hints["repository_secret_name"])
             check_type(argname="argument source_secret", value=source_secret, expected_type=type_hints["source_secret"])
             check_type(argname="argument source_secret_json_field", value=source_secret_json_field, expected_type=type_hints["source_secret_json_field"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "github_token_secret": github_token_secret,
             "repository": repository,
             "repository_secret_name": repository_secret_name,
@@ -479,14 +437,14 @@ class ActionSecretProps:
             self._values["source_secret_json_field"] = source_secret_json_field
 
     @builtins.property
-    def github_token_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
+    def github_token_secret(self) -> _aws_cdk_aws_secretsmanager_ceddda9d.ISecret:
         '''(experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
 
         :stability: experimental
         '''
         result = self._values.get("github_token_secret")
         assert result is not None, "Required property 'github_token_secret' is missing"
-        return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
+        return typing.cast(_aws_cdk_aws_secretsmanager_ceddda9d.ISecret, result)
 
     @builtins.property
     def repository(self) -> "IGitHubRepository":
@@ -509,14 +467,14 @@ class ActionSecretProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def source_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
+    def source_secret(self) -> _aws_cdk_aws_secretsmanager_ceddda9d.ISecret:
         '''(experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
 
         :stability: experimental
         '''
         result = self._values.get("source_secret")
         assert result is not None, "Required property 'source_secret' is missing"
-        return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
+        return typing.cast(_aws_cdk_aws_secretsmanager_ceddda9d.ISecret, result)
 
     @builtins.property
     def source_secret_json_field(self) -> typing.Optional[builtins.str]:
@@ -544,7 +502,7 @@ class ActionSecretProps:
 
 
 class GitHubResource(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-github.GitHubResource",
 ):
@@ -554,18 +512,18 @@ class GitHubResource(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         create_request_endpoint: builtins.str,
         delete_request_endpoint: builtins.str,
-        github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+        github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
         create_request_payload: typing.Optional[builtins.str] = None,
         create_request_result_parameter: typing.Optional[builtins.str] = None,
         delete_request_payload: typing.Optional[builtins.str] = None,
         update_request_endpoint: typing.Optional[builtins.str] = None,
         update_request_payload: typing.Optional[builtins.str] = None,
-        write_response_to_ssm_parameter: typing.Optional[aws_cdk.aws_ssm.IParameter] = None,
+        write_response_to_ssm_parameter: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.IParameter] = None,
     ) -> None:
         '''
         :param scope: -
@@ -583,22 +541,7 @@ class GitHubResource(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                create_request_endpoint: builtins.str,
-                delete_request_endpoint: builtins.str,
-                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
-                create_request_payload: typing.Optional[builtins.str] = None,
-                create_request_result_parameter: typing.Optional[builtins.str] = None,
-                delete_request_payload: typing.Optional[builtins.str] = None,
-                update_request_endpoint: typing.Optional[builtins.str] = None,
-                update_request_payload: typing.Optional[builtins.str] = None,
-                write_response_to_ssm_parameter: typing.Optional[aws_cdk.aws_ssm.IParameter] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f466d2485a28b3266178a151db687ae71a1f575c855ad518657d2d9f76b8572b)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitHubResourceProps(
@@ -637,13 +580,13 @@ class GitHubResourceProps:
         *,
         create_request_endpoint: builtins.str,
         delete_request_endpoint: builtins.str,
-        github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+        github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
         create_request_payload: typing.Optional[builtins.str] = None,
         create_request_result_parameter: typing.Optional[builtins.str] = None,
         delete_request_payload: typing.Optional[builtins.str] = None,
         update_request_endpoint: typing.Optional[builtins.str] = None,
         update_request_payload: typing.Optional[builtins.str] = None,
-        write_response_to_ssm_parameter: typing.Optional[aws_cdk.aws_ssm.IParameter] = None,
+        write_response_to_ssm_parameter: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.IParameter] = None,
     ) -> None:
         '''
         :param create_request_endpoint: (experimental) The GitHub api endpoint url for creating resources in format: ``POST /repos/OWNER/REPO/issues``. This is called when the GitHubResource is created. Example:: const createRequestEndpoint = 'POST /repos/octocat/Hello-World/issues'
@@ -659,20 +602,7 @@ class GitHubResourceProps:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                create_request_endpoint: builtins.str,
-                delete_request_endpoint: builtins.str,
-                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
-                create_request_payload: typing.Optional[builtins.str] = None,
-                create_request_result_parameter: typing.Optional[builtins.str] = None,
-                delete_request_payload: typing.Optional[builtins.str] = None,
-                update_request_endpoint: typing.Optional[builtins.str] = None,
-                update_request_payload: typing.Optional[builtins.str] = None,
-                write_response_to_ssm_parameter: typing.Optional[aws_cdk.aws_ssm.IParameter] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__dcd401c285b263f3dab91e46a4fd529df29de7192462c00e2c9e1bf4f73d543b)
             check_type(argname="argument create_request_endpoint", value=create_request_endpoint, expected_type=type_hints["create_request_endpoint"])
             check_type(argname="argument delete_request_endpoint", value=delete_request_endpoint, expected_type=type_hints["delete_request_endpoint"])
             check_type(argname="argument github_token_secret", value=github_token_secret, expected_type=type_hints["github_token_secret"])
@@ -682,7 +612,7 @@ class GitHubResourceProps:
             check_type(argname="argument update_request_endpoint", value=update_request_endpoint, expected_type=type_hints["update_request_endpoint"])
             check_type(argname="argument update_request_payload", value=update_request_payload, expected_type=type_hints["update_request_payload"])
             check_type(argname="argument write_response_to_ssm_parameter", value=write_response_to_ssm_parameter, expected_type=type_hints["write_response_to_ssm_parameter"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "create_request_endpoint": create_request_endpoint,
             "delete_request_endpoint": delete_request_endpoint,
             "github_token_secret": github_token_secret,
@@ -737,14 +667,14 @@ class GitHubResourceProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def github_token_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
+    def github_token_secret(self) -> _aws_cdk_aws_secretsmanager_ceddda9d.ISecret:
         '''(experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
 
         :stability: experimental
         '''
         result = self._values.get("github_token_secret")
         assert result is not None, "Required property 'github_token_secret' is missing"
-        return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
+        return typing.cast(_aws_cdk_aws_secretsmanager_ceddda9d.ISecret, result)
 
     @builtins.property
     def create_request_payload(self) -> typing.Optional[builtins.str]:
@@ -829,13 +759,13 @@ class GitHubResourceProps:
     @builtins.property
     def write_response_to_ssm_parameter(
         self,
-    ) -> typing.Optional[aws_cdk.aws_ssm.IParameter]:
+    ) -> typing.Optional[_aws_cdk_aws_ssm_ceddda9d.IParameter]:
         '''(experimental) The response body of the last GitHub api request will be written to this ssm parameter.
 
         :stability: experimental
         '''
         result = self._values.get("write_response_to_ssm_parameter")
-        return typing.cast(typing.Optional[aws_cdk.aws_ssm.IParameter], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ssm_ceddda9d.IParameter], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -903,9 +833,7 @@ class _IGitHubRepositoryProxy:
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__58a2e1254c75d00030586c20d2ad2539cb2097fa5838210654a45ac5e1097329)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -923,9 +851,7 @@ class _IGitHubRepositoryProxy:
     @owner.setter
     def owner(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__23b93f41e494ad1fe11640aa0c493d9b0995a544b87fc6cdac994a0166f8899c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "owner", value)
 
@@ -944,3 +870,97 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__f04c62400886edffc3fa16f507af446ec4ad2a2e1089c6fa98e572bd3f8f6d32(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    environment: builtins.str,
+    github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    repository: IGitHubRepository,
+    repository_secret_name: builtins.str,
+    source_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    source_secret_json_field: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__19458ba05b3c10d04dcaf1e2a1d6e605d210b81e75d59a1e981178b6f3a7adc5(
+    *,
+    environment: builtins.str,
+    github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    repository: IGitHubRepository,
+    repository_secret_name: builtins.str,
+    source_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    source_secret_json_field: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c940bc65eade9a56398b94487dd33d25ad7688152385eb63583bfa67ab511b54(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    repository: IGitHubRepository,
+    repository_secret_name: builtins.str,
+    source_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    source_secret_json_field: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__914972a093356563c05a92c585205514c45295c3c26e5e0063ed507e8833ba01(
+    *,
+    github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    repository: IGitHubRepository,
+    repository_secret_name: builtins.str,
+    source_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    source_secret_json_field: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f466d2485a28b3266178a151db687ae71a1f575c855ad518657d2d9f76b8572b(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    create_request_endpoint: builtins.str,
+    delete_request_endpoint: builtins.str,
+    github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    create_request_payload: typing.Optional[builtins.str] = None,
+    create_request_result_parameter: typing.Optional[builtins.str] = None,
+    delete_request_payload: typing.Optional[builtins.str] = None,
+    update_request_endpoint: typing.Optional[builtins.str] = None,
+    update_request_payload: typing.Optional[builtins.str] = None,
+    write_response_to_ssm_parameter: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.IParameter] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dcd401c285b263f3dab91e46a4fd529df29de7192462c00e2c9e1bf4f73d543b(
+    *,
+    create_request_endpoint: builtins.str,
+    delete_request_endpoint: builtins.str,
+    github_token_secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    create_request_payload: typing.Optional[builtins.str] = None,
+    create_request_result_parameter: typing.Optional[builtins.str] = None,
+    delete_request_payload: typing.Optional[builtins.str] = None,
+    update_request_endpoint: typing.Optional[builtins.str] = None,
+    update_request_payload: typing.Optional[builtins.str] = None,
+    write_response_to_ssm_parameter: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.IParameter] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__58a2e1254c75d00030586c20d2ad2539cb2097fa5838210654a45ac5e1097329(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__23b93f41e494ad1fe11640aa0c493d9b0995a544b87fc6cdac994a0166f8899c(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
